@@ -91,6 +91,7 @@ describe 'neutron::config' do
         :plugin_cisco_config           => config_hash,
         :plugin_midonet_config         => config_hash,
         :plugin_plumgrid_config        => config_hash,
+        :plugin_nsx_config             => config_hash,
         :plugin_opencontrail_config    => config_hash,
         :plugin_nuage_config           => config_hash,
         :plugin_ml2_config             => config_hash
@@ -133,6 +134,12 @@ describe 'neutron::config' do
       is_expected.to contain_neutron_plugin_plumgrid('DEFAULT/baz').with_ensure('absent')
     end
 
+    it 'configures arbitrary neutron_plugin_nsx configurations' do
+      is_expected.to contain_neutron_plugin_nsx('DEFAULT/foo').with_value('fooValue')
+      is_expected.to contain_neutron_plugin_nsx('DEFAULT/bar').with_value('barValue')
+      is_expected.to contain_neutron_plugin_nsx('DEFAULT/baz').with_ensure('absent')
+    end
+
     it 'configures arbitrary neutron_plugin_opencontrail configurations' do
       is_expected.to contain_neutron_plugin_opencontrail('DEFAULT/foo').with_value('fooValue')
       is_expected.to contain_neutron_plugin_opencontrail('DEFAULT/bar').with_value('barValue')
